@@ -1,5 +1,5 @@
-# Copyright (C) 2008 PreludeIDS Technologies. All Rights Reserved.
-# Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
+# Copyright (C) 2008-2016 CS-SI. All Rights Reserved.
+# Author: Yoann Vandoorselaere <yoannv@gmail.com>
 #
 # This file is part of the Prewikka program.
 #
@@ -13,12 +13,13 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; see the file COPYING.  If not, write to
-# the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 import time
 import socket
+from prewikka import env
 
 resolver = None
 import_fail = None
@@ -51,7 +52,7 @@ class DNSResolver:
 
     def _resolve_cb(self, (ans, auth, add), ptr, resolve_cb):
         self._query -= 1
-        name = unicode(ans[0].payload.name)
+        name = str(ans[0].payload.name)
 
         resolve_cb(name)
 
@@ -120,6 +121,9 @@ class AddressResolve:
     def __init__(self, addr, format=None):
         global resolver
 
+        if not isinstance(addr, str):
+            raise TypeError('AddressResolve expects a valid IP address to resolve')
+
         self._addr = addr
         self._name = None
         self._formater = format
@@ -128,7 +132,7 @@ class AddressResolve:
             resolver.resolve(addr, self._resolve_cb)
 
     def __len__(self):
-        return len(unicode(self))
+        return len(str(self))
 
     def resolveSucceed(self):
         if self._name:
@@ -142,9 +146,6 @@ class AddressResolve:
 
         return self._name or self._addr
 
-    def __repr__(self):
-        return unicode(self)
-
 
 def process(timeout=0):
     global resolver
@@ -153,14 +154,14 @@ def process(timeout=0):
         resolver.process(timeout)
 
 
-def init(env):
+def init():
     global resolver
 
     if env.dns_max_delay == -1:
         return
 
     if import_fail:
-       env.log.warning("Asynchronous DNS resolution disabled: twisted.names and twisted.internet required: %s" % err)
+       env.log.warning(_("Asynchronous DNS resolution disabled: twisted.names and twisted.internet required: %s") % err)
        return
 
     resolver = DNSResolver()
